.. :changelog:

History
=======

Version 2.0.0 (2019-08-26)
--------------------------

* BREAKING: Complete redesign of internal API.
* Payment becomes swappable model - like Django's User model
* Payment acts as customizable interface to PaymentProcessor
* see documentation for full list
